# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/lane.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/lane.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n proto/hdmap_lib/proto/lane.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xc1\x0e\n\x04Lane\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\"\n\x04type\x18\x02 \x01(\x0e\x32\x14.hdmap_lib.Lane.Type\x12+\n\x11left_lane_marking\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12,\n\x12right_lane_marking\x18\x05 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12+\n\tturn_type\x18\x07 \x01(\x0e\x32\x18.hdmap_lib.Lane.TurnType\x12-\n\nspeed_info\x18\x08 \x01(\x0b\x32\x19.hdmap_lib.Lane.SpeedInfo\x12\'\n\rcentral_curve\x18\t \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\x0e\n\x06length\x18\n \x01(\x01\x12)\n\x12successor_lane_ids\x18\x0b \x03(\x0b\x32\r.hdmap_lib.Id\x12+\n\x14predecessor_lane_ids\x18\x0c \x03(\x0b\x32\r.hdmap_lib.Id\x12\x34\n\x1dleft_neighbor_forward_lane_id\x18\r \x01(\x0b\x32\r.hdmap_lib.Id\x12\x35\n\x1eright_neighbor_forward_lane_id\x18\x0e \x01(\x0b\x32\r.hdmap_lib.Id\x12\x35\n\x1eleft_neighbor_reverse_lane_ids\x18\x0f \x03(\x0b\x32\r.hdmap_lib.Id\x12\x36\n\x1fright_neighbor_reverse_lane_ids\x18\x10 \x03(\x0b\x32\r.hdmap_lib.Id\x12\"\n\x0bjunction_id\x18\x11 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x13\n\x08priority\x18\x13 \x01(\x05:\x01\x30\x12(\n\nattributes\x18\x12 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x17\n\x0fis_waiting_area\x18\x14 \x01(\x08\x12\x17\n\x0fis_virtual_lane\x18\x19 \x01(\x08\x12\r\n\x05width\x18\x1a \x01(\x01\x12\x1e\n\x07road_id\x18\x1b \x01(\x0b\x32\r.hdmap_lib.Id\x12<\n%left_neighbor_forward_driving_lane_id\x18\x1c \x01(\x0b\x32\r.hdmap_lib.Id\x12=\n&right_neighbor_forward_driving_lane_id\x18\x1d \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1a\n\x12lane_section_index\x18\x1e \x01(\x05\x12#\n\x07polygon\x18\x1f \x01(\x0b\x32\x12.hdmap_lib.Polygon\x1a<\n\tSpeedInfo\x12\x0e\n\x03min\x18\x01 \x01(\x01:\x01\x30\x12\x0f\n\x03max\x18\x02 \x01(\x01:\x02\x36\x30\x12\x0e\n\x06prefer\x18\x03 \x01(\x01\"\xbb\x03\n\x04Type\x12\x08\n\x04NONE\x10\x01\x12\x0b\n\x07\x44RIVING\x10\x02\x12\n\n\x06\x42IKING\x10\x03\x12\x0c\n\x08SHOULDER\x10\x04\x12\r\n\tEMERGENCY\x10\x05\x12\x07\n\x03\x42US\x10\x06\x12\x0e\n\nACCELERATE\x10\x07\x12\x0e\n\nDECELERATE\x10\x08\x12\x08\n\x04\x46\x41ST\x10\t\x12\x08\n\x04SLOW\x10\n\x12\x0f\n\x0bOVERTAKEING\x10\x0b\x12\n\n\x06\x45SCAPE\x10\x0c\x12\t\n\x05TIDAL\x10\r\x12\x12\n\x0eVARIABLE_GUIDE\x10\x0e\x12\x15\n\x11VER_TRUCK_DRIVING\x10\x0f\x12\x15\n\x11HOR_TRUCK_DRIVING\x10\x10\x12\x15\n\x11VER_HOR_EMERGENCY\x10\x11\x12\x12\n\x0eVER_HOR_EXPAND\x10\x12\x12\x16\n\x12YARD_TRUCK_DRIVING\x10\x13\x12\x16\n\x12\x44OCK_TRUCK_DRIVING\x10\x14\x12\t\n\x05\x43RANE\x10\x15\x12\n\n\x06GANTRY\x10\x16\x12\n\n\x06\x42RIDGE\x10\x17\x12\x10\n\x0cSHUTTLE_DOOR\x10\x18\x12\t\n\x05\x43HECK\x10\x19\x12\x0c\n\x08STACK_UP\x10\x1a\x12\n\n\x06GIRDER\x10\x1b\x12\x0c\n\x08\x42UNDLING\x10\x1c\x12\t\n\x05\x46LOOD\x10\x1d\"\xd7\x02\n\x08TurnType\x12\r\n\tNONE_TURN\x10\x01\x12\x0b\n\x07NO_TURN\x10\x02\x12\r\n\tLEFT_TURN\x10\x03\x12\x0e\n\nRIGHT_TURN\x10\x04\x12\n\n\x06U_TURN\x10\x05\x12\x12\n\x0eLEFT_TURN_WAIT\x10\x06\x12\x0f\n\x0bLEFT_U_TURN\x10\x07\x12\x10\n\x0cRIGHT_U_TURN\x10\x08\x12\x12\n\x0eSTRAIGHT_RIGHT\x10\t\x12\x11\n\rSTRAIGHT_LEFT\x10\n\x12\x0e\n\nLEFT_RIGHT\x10\x0b\x12\x17\n\x13LEFT_STRAIGHT_RIGHT\x10\x0c\x12\x19\n\x15RIGHT_STRAIGHT_U_TURN\x10\r\x12\x18\n\x14LEFT_STRAIGHT_U_TURN\x10\x0e\x12\x15\n\x11LEFT_RIGHT_U_TURN\x10\x0f\x12\x1e\n\x1aLEFT_STRAIGHT_RIGHT_U_TURN\x10\x10\x12\x11\n\rRIGHT_OBLIQUE\x10\x11'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_LANE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Lane.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVING', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BIKING', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHOULDER', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUS', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCELERATE', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECELERATE', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAST', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERTAKEING', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ESCAPE', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIDAL', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VARIABLE_GUIDE', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_TRUCK_DRIVING', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOR_TRUCK_DRIVING', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_HOR_EMERGENCY', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VER_HOR_EXPAND', index=17, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YARD_TRUCK_DRIVING', index=18, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOCK_TRUCK_DRIVING', index=19, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRANE', index=20, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GANTRY', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE', index=22, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHUTTLE_DOOR', index=23, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=24, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STACK_UP', index=25, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIRDER', index=26, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUNDLING', index=27, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOOD', index=28, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1225,
  serialized_end=1668,
)
_sym_db.RegisterEnumDescriptor(_LANE_TYPE)

_LANE_TURNTYPE = _descriptor.EnumDescriptor(
  name='TurnType',
  full_name='hdmap_lib.Lane.TurnType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE_TURN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_TURN', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_TURN', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_TURN_WAIT', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_U_TURN', index=6, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_U_TURN', index=7, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT_RIGHT', index=8, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT_LEFT', index=9, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_RIGHT', index=10, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_RIGHT', index=11, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_STRAIGHT_U_TURN', index=12, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_U_TURN', index=13, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_RIGHT_U_TURN', index=14, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_STRAIGHT_RIGHT_U_TURN', index=15, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_OBLIQUE', index=16, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1671,
  serialized_end=2014,
)
_sym_db.RegisterEnumDescriptor(_LANE_TURNTYPE)


_LANE_SPEEDINFO = _descriptor.Descriptor(
  name='SpeedInfo',
  full_name='hdmap_lib.Lane.SpeedInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='hdmap_lib.Lane.SpeedInfo.min', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='hdmap_lib.Lane.SpeedInfo.max', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(60),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefer', full_name='hdmap_lib.Lane.SpeedInfo.prefer', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1162,
  serialized_end=1222,
)

_LANE = _descriptor.Descriptor(
  name='Lane',
  full_name='hdmap_lib.Lane',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Lane.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Lane.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_lane_marking', full_name='hdmap_lib.Lane.left_lane_marking', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_lane_marking', full_name='hdmap_lib.Lane.right_lane_marking', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='turn_type', full_name='hdmap_lib.Lane.turn_type', index=4,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_info', full_name='hdmap_lib.Lane.speed_info', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='hdmap_lib.Lane.central_curve', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='hdmap_lib.Lane.length', index=7,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successor_lane_ids', full_name='hdmap_lib.Lane.successor_lane_ids', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predecessor_lane_ids', full_name='hdmap_lib.Lane.predecessor_lane_ids', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_forward_lane_id', full_name='hdmap_lib.Lane.left_neighbor_forward_lane_id', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_forward_lane_id', full_name='hdmap_lib.Lane.right_neighbor_forward_lane_id', index=11,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_reverse_lane_ids', full_name='hdmap_lib.Lane.left_neighbor_reverse_lane_ids', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_reverse_lane_ids', full_name='hdmap_lib.Lane.right_neighbor_reverse_lane_ids', index=13,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='hdmap_lib.Lane.junction_id', index=14,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='hdmap_lib.Lane.priority', index=15,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Lane.attributes', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_waiting_area', full_name='hdmap_lib.Lane.is_waiting_area', index=17,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual_lane', full_name='hdmap_lib.Lane.is_virtual_lane', index=18,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='hdmap_lib.Lane.width', index=19,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_id', full_name='hdmap_lib.Lane.road_id', index=20,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_neighbor_forward_driving_lane_id', full_name='hdmap_lib.Lane.left_neighbor_forward_driving_lane_id', index=21,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_neighbor_forward_driving_lane_id', full_name='hdmap_lib.Lane.right_neighbor_forward_driving_lane_id', index=22,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_section_index', full_name='hdmap_lib.Lane.lane_section_index', index=23,
      number=30, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Lane.polygon', index=24,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LANE_SPEEDINFO, ],
  enum_types=[
    _LANE_TYPE,
    _LANE_TURNTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=157,
  serialized_end=2014,
)

_LANE_SPEEDINFO.containing_type = _LANE
_LANE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['type'].enum_type = _LANE_TYPE
_LANE.fields_by_name['left_lane_marking'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['right_lane_marking'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['turn_type'].enum_type = _LANE_TURNTYPE
_LANE.fields_by_name['speed_info'].message_type = _LANE_SPEEDINFO
_LANE.fields_by_name['central_curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_LANE.fields_by_name['successor_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['predecessor_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_forward_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_forward_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_reverse_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_reverse_lane_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['junction_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_LANE.fields_by_name['road_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['left_neighbor_forward_driving_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['right_neighbor_forward_driving_lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_LANE.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_LANE_TYPE.containing_type = _LANE
_LANE_TURNTYPE.containing_type = _LANE
DESCRIPTOR.message_types_by_name['Lane'] = _LANE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Lane = _reflection.GeneratedProtocolMessageType('Lane', (_message.Message,), {

  'SpeedInfo' : _reflection.GeneratedProtocolMessageType('SpeedInfo', (_message.Message,), {
    'DESCRIPTOR' : _LANE_SPEEDINFO,
    '__module__' : 'proto.hdmap_lib.proto.lane_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.Lane.SpeedInfo)
    })
  ,
  'DESCRIPTOR' : _LANE,
  '__module__' : 'proto.hdmap_lib.proto.lane_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Lane)
  })
_sym_db.RegisterMessage(Lane)
_sym_db.RegisterMessage(Lane.SpeedInfo)


# @@protoc_insertion_point(module_scope)



from typing import List, Tuple

import proto.grpc.hdmapimpl_pb2 as hdmapimpl_pb2

def MapGirderDirection(num):
    if num == 1:
        return hdmapimpl_pb2.Vessel.GirderDirection.NORMAL
    elif num == 2:
        return hdmapimpl_pb2.Vessel.GirderDirection.REVERSE
    elif num == 3:
        return hdmapimpl_pb2.Vessel.GirderDirection.BOTH_EAST
    elif num == 4:
        return hdmapimpl_pb2.Vessel.GirderDirection.BOTH_WEST
    return hdmapimpl_pb2.Vessel.GirderDirection.NORMAL

class Vessel:
  def __init__(self) -> None:
    self._head_x = 0.0
    self._head_y = 0.0
    self._rear_x = 0.0
    self._rear_y = 0.0
    self._head_bridge = ""
    self._leave_bridge = ""
    self._east_area_direction = 0
    self._east_working_area_direction = 0
    self._west_working_area_direction = 0
    self._west_area_direction = 0
    
  def head_x(self):
    return self._head_x
  
  def set_head_x(self, head_x):
    self._head_x = head_x
    
  def head_y(self):
    return self._head_y
  
  def set_head_x(self, head_y):
    self._head_y = head_y
    
  def rear_x(self):
    return self._rear_x
  
  def set_rear_x(self, rear_x):
    self._rear_x = rear_x
    
  def rear_y(self):
    return self._rear_y
  
  def set_rear_y(self, rear_y):
    self._rear_y = rear_y
    
  def head_bridge(self):
    return self._head_bridge
  
  def set_head_x(self, head_bridge):
    self._head_bridge = head_bridge
    
  def leave_bridge(self):
    return self._leave_bridge
  
  def set_leave_bridge(self, leave_bridge):
    self._leave_bridge = leave_bridge
    
  def east_area_direction(self):
    return self._east_area_direction
  
  def set_east_area_direction(self, east_area_direction):
    self._east_area_direction = east_area_direction
    
  def east_working_area_direction(self):
    return self._east_working_area_direction
  
  def set_east_working_area_direction(self, east_working_area_direction):
    self._east_working_area_direction = east_working_area_direction
    
  def west_working_area_direction(self):
    return self._west_working_area_direction
  
  def set_west_working_area_direction(self, west_working_area_direction):
    self._west_working_area_direction = west_working_area_direction
    
  def west_area_direction(self):
    return self._west_area_direction
  
  def set_west_area_direction(self, west_area_direction):
    self._west_area_direction = west_area_direction
    
def build_vessel_status(vessels:List[Vessel]):
  vessel_status = hdmapimpl_pb2.VesselStatus()
  for vessel in vessels:
    one_vessel_status = vessel_status.vessels.add()
    one_vessel_status.head.x = vessel.head_x()
    one_vessel_status.head.y = vessel.head_y()
    one_vessel_status.rear.x = vessel.rear_x()
    one_vessel_status.rear.y = vessel.rear_y()
    one_vessel_status.head_bridge = vessel.head_bridge()
    one_vessel_status.leave_bridge = vessel.leave_bridge()
    one_vessel_status.east_area_girder_direction = MapGirderDirection(vessel.east_area_direction)
    one_vessel_status.east_working_area_girder_direction = MapGirderDirection(vessel.east_working_area_direction)
    one_vessel_status.west_working_area_girder_direction = MapGirderDirection(vessel.west_working_area_direction)
    one_vessel_status.west_area_girder_direction = MapGirderDirection(vessel.west_area_direction)
  return vessel_status


# -*- coding: utf-8 -*-

from tokenize import Double
from typing import Any, List, Tuple


def SetRuntimeFlags(flag_file_content: str, program_name: str,
                    errors_are_fatal: bool) -> bool: ...


def GetRuntimeFlags() -> str: ...


def InitLogging(program_name: str) -> None : ...


class Vec2d:
    def __init__(self, x: float, y: float) -> None: ...

    def CreateUnitVec2d(self, angle: float) -> None: ...

    def x(self) -> float: ...

    def y(self) -> float: ...

    def set_x(self, value: float) -> None: ...

    def set_y(self, value: float) -> None: ...

    def Length(self) -> float: ...

    def LengthSquare(self) -> float: ...

    def Angle(self) -> float: ...

    def Normalize(self) -> None: ...

    def DistanceTo(self, other: Vec2d) -> float: ...

    def DistanceSquareTo(self, other: Vec2d) -> float: ...

    def CrossProd(self, other: Vec2d) -> float: ...

    def InnerProd(self, other: Vec2d) -> float: ...

    def rotate(self, angle: float) -> Vec2d: ...

    def DebugString(self) -> str: ...


class SDPoint(Vec2d):
    def __init__(self, s: float, d: float) -> None: ...

    def s(self) -> float: ...

    def d(self) -> float: ...

    def set_s(self, value: float) -> None: ...

    def set_d(self, value: float) -> None: ...

    def DebugString(self) -> str: ...


class LineSegment2d:
    def __init__(self, start: Vec2d, end: Vec2d) -> None: ...

    def start(self) -> Vec2d: ...

    def end(self) -> Vec2d: ...

    def unit_direction(self) -> Vec2d: ...

    def center(self) -> Vec2d: ...

    def heading(self) -> float: ...

    def cos_heading(self) -> float: ...

    def sin_heading(self) -> float: ...

    def length(self) -> float: ...

    def length_sqr(self) -> float: ...

    def DistanceTo(self, point: Vec2d, nearest_pt: Vec2d = None) -> float: ...

    def DistanceSquareTo(self, point: Vec2d,
                         nearest_pt: Vec2d = None) -> float: ...

    def IsPointIn(self, point: Vec2d) -> bool: ...

    def HasIntersect(self, other_segment: LineSegment2d) -> bool: ...

    def GetIntersect(self, other_segment: LineSegment2d,
                     point: Vec2d) -> bool: ...

    def ProjectOntoUnit(self, point: Vec2d) -> float: ...

    def ProductOntoUnit(self, point: Vec2d) -> float: ...

    def GetPerpendicularFoot(
        self, point: Vec2d, foot_point: Vec2d) -> float: ...

    def DebugString(self) -> str: ...


class AABox2d:

    def __init__(self, center: Vec2d, length: float, width: float) -> None: ...

    def __init__(self, one_corner: Vec2d, opposite_corner: Vec2d) -> None: ...

    def __init__(self, points: List[Vec2d]) -> None: ...

    def center(self) -> Vec2d: ...

    def center_x(self) -> float: ...

    def center_y(self) -> float: ...

    def length(self) -> float: ...

    def width(self) -> float: ...

    def half_length(self) -> float: ...

    def half_width(self) -> float: ...

    def area(self) -> float: ...

    def min_x(self) -> float: ...

    def max_x(self) -> float: ...

    def min_y(self) -> float: ...

    def max_y(self) -> float: ...

    def GetAllCorners(self) -> List[Vec2d]: ...

    def IsPointIn(self, point: Vec2d) -> bool: ...

    def IsPointOnBoundary(self, point: Vec2d) -> bool: ...

    def DistanceTo(self, object: Any[Vec2d, AABox2d]) -> float: ...

    def HasOverlap(self, box: AABox2d) -> bool: ...

    def GetOverlap(self, box: AABox2d, is_union: bool) -> float: ...

    def Shift(self, shift_vec: Vec2d) -> None: ...

    def MergeFromAABox2d(self, other_box: AABox2d) -> None: ...

    def MergeFromVec2d(self, other_point: Vec2d) -> None: ...

    def DebugString(self) -> str: ...


class Box2d:
    def __init__(self, center: Vec2d, heading: float,
                 length: float, width: float) -> None: ...

    def __init__(self, axis: LineSegment2d, width: Vec2d) -> None: ...

    def __init__(self, aabox: AABox2d) -> None: ...

    @staticmethod
    def CreateAABox(one_corner: Vec2d, opposite_corner: Vec2d) -> Box2d: ...

    @staticmethod
    def CreateAABox(points: List[Vec2d]) -> Box2d: ...

    @staticmethod
    def CreateBox2d(sepoints: List[Vec2d]) -> Box2d: ...

    def CreateMergedBox2d(self, box: Box2d) -> Box2d: ...

    def center(self) -> Vec2d: ...

    def corners(self) -> List[Vec2d]: ...

    def center_x(self) -> float: ...

    def center_y(self) -> float: ...

    def length(self) -> float: ...

    def width(self) -> float: ...

    def half_length(self) -> float: ...

    def half_width(self) -> float: ...

    def heading(self) -> float: ...

    def cos_heading(self) -> float: ...

    def sin_heading(self) -> float: ...

    def area(self) -> float: ...

    def diagonal(self) -> float: ...

    def GetAllCorners(self) -> List[Vec2d]: ...

    def IsPointIn(self, point: Vec2d) -> bool: ...

    def IsPointOnBoundary(self, point: Vec2d) -> bool: ...

    def DistanceTo(self, object: Any[Vec2d, LineSegment2d, Box2d]): ...

    def DistanceToVec2d(self, point: Vec2d) -> float: ...

    def DistanceToLineSegment2d(
        self, line_segment: LineSegment2d) -> float: ...

    def DistanceToBox2d(self, box: Box2d) -> float: ...

    def HasOverlap(self, object: Any[LineSegment2d, Box2d]) -> bool: ...

    def AreaOfUnion(self, box: Box2d) -> float: ...

    def AreaOfIntersection(self, box: Box2d) -> float: ...

    def IoU(self, box: Box2d) -> float: ...

    def GetAABox(self) -> AABox2d: ...

    def RotateFromCenter(self, rotate_angle: float) -> None: ...

    def Shift(self, shift_vec: Vec2d) -> None: ...

    def LongitudinalExtend(self, extension_length: float) -> None: ...

    def LateralExtend(self, extension_length: float) -> None: ...

    def DebugString(self) -> str: ...

    def InitCorners(self) -> None: ...

    def max_x(self) -> float: ...

    def min_x(self) -> float: ...

    def max_y(self) -> float: ...

    def min_y(self) -> float: ...

    def IsValid(self) -> bool: ...


class Curve:

    def x(s: float) -> float: ...

    def y(s: float) -> float: ...

    def FitCurve(xs: List[float], yx: List[float]) -> None: ...


class Polygon2d:

    def __init__(self, box: Box2d) -> None: ...

    def __init__(self, points: List[Vec2d]) -> None: ...

    def __init__(self, polygon: Polygon2d) -> None: ...

    def points(self) -> List[Vec2d]: ...

    def line_segments(self) -> List[LineSegment2d]: ...

    def num_points(self) -> int: ...

    def is_convex(self) -> bool: ...

    def area(self) -> float: ...

    def DistanceToBoundary(self, point: Vec2d) -> float: ...

    def DistanceTo(self, point: Vec2d) -> float: ...

    def DistanceTo(self, line_segment: LineSegment2d) -> float: ...

    def DistanceTo(self, box: Box2d) -> float: ...

    def DistanceTo(self, polygon: Polygon2d) -> float: ...

    def DistanceSquareTo(self, point: Vec2d) -> float: ...

    def IsPointIn(self, point: Vec2d) -> bool: ...

    def IsPointOnBoundary(self, point: Vec2d) -> bool: ...

    def Contains(self, line_segment: LineSegment2d) -> bool: ...

    def Contains(self, polygon: Polygon2d) -> bool: ...

    @staticmethod
    def ComputeConvexHull(points: List[Vec2d], polygon: Polygon2d) -> None: ...

    def HasOverlap(self, line_segment: LineSegment2d) -> bool: ...

    def GetOverlap(self, line_segment: LineSegment2d,
                   first: Vec2d, last: Vec2d) -> bool: ...

    def GetAllOverlaps(
        self, line_segment: LineSegment2d) -> List[LineSegment2d]: ...

    def HasOverlap(self, polygon: Polygon2d) -> bool: ...

    def ComputeOverlap(self, other_polygon: Polygon2d,
                       overlap_polygon: Polygon2d) -> bool: ...

    def AABoundingBox(self) -> AABox2d: ...

    def BoundingBoxWithHeading(self, heading: float) -> Box2d: ...

    def MinAreaBoundingBox(self) -> Box2d: ...

    def ExtremePoints(self, heading: float, first: Vec2d,
                      last: Vec2d) -> None: ...

    def ExpandByDistance(self, distance) -> Polygon2d: ...

    def DebugString(self) -> str: ...

    def min_x(self) -> float: ...

    def max_x(self) -> float: ...

    def min_y(self) -> float: ...

    def max_y(self) -> float: ...


class HDMapManager:
    @ staticmethod
    def LoadMap(map_file_path: str, business_scene: str) -> bool: ...

    @ staticmethod
    def LoadMapDir(map_dir: str, business_scene: str) -> bool: ...

    @ staticmethod
    def Reload(vessel_status_bytes: str) -> bool: ...

    @staticmethod
    def ReloadForHdmapService(
        vessels: List[List[float]], vessel_uuids: List[str]) -> bool: ...
    
    @staticmethod
    def PreprocessForHdmapService(
        map_file_path: str, business_scene: str, save_dir: str) -> bool: ...

    @staticmethod
    def TestVesselFromVecList(
        vessels: List[List[float]]) -> List[List[float]]: ...

    @ staticmethod
    def GetHDMap() -> HDMap: ...

    @ staticmethod
    def GetReloadVesselStatus() -> List[HdmapVessel]: ...

    @ staticmethod
    def GetVesselStatus() -> str: ...


class HDMap:
    def LoadMap(self, map_file_path: str, business_scene: str) -> bool: ...
    
    def LoadMapWithMode(self, map_file_path: str, business_scene: str, mode: int) -> bool: ...

    def LoadGround(self, ground_file_path: str) -> bool: ...

    def LoadMapDir(self, map_dir: str, business_scene: str) -> bool: ...

    def Reload(self, vessel_status_bytes: str) -> bool: ...

    def GetDockProjection(self, point: Vec2d) -> Tuple[float, float]: ...
    
    def ValidateForHdmapService(
        vessels: List[List[float]], vessel_flag: List[str]) -> Tuple[bool, List[List[List[str]]], List[HdmapVessel]]: ...

    def GetDockDynamicBlockByIndex(
        self, vessel_uuid: str, index: int) -> List[BlockLane]: ...
    
    def JudgeGirderDirection(self, solved_vessels: List[CloudServiceVessel], cur_vessel: CloudServiceVessel) -> Tuple[int, CloudServiceVessel, GirderAffect, GirderAffect]: ...

    def GetMap(self) -> MapInfo: ...
    
    def GetMd5(self) -> str: ...

    def GetLineById(self, id: IdInfo) -> LineStringDataInfo: ...

    def GetLaneById(self, id: IdInfo) -> LaneInfo: ...

    def GetRoadById(self, id: IdInfo) -> RoadInfo: ...

    def GetJunctionById(self, id: IdInfo) -> JunctionInfo: ...

    def GetCrosswalkById(self, id: IdInfo) -> CrosswalkInfo: ...

    def GetStopLineById(self, id: IdInfo) -> StopLineInfo: ...

    def GetSignalById(self, id: IdInfo) -> SignalInfo: ...

    def GetPullOverRegionById(self, id: IdInfo) -> PullOverRegionInfo: ...

    def GetParkingSpaceById(self, id: IdInfo) -> ParkingSpaceInfo: ...

    def GetPoiById(self, id: IdInfo) -> PoiInfo: ...

    def GetObjectById(self, id: IdInfo) -> ObjectInfo: ...

    def GetLanes(self, point: Vec2d, distance: float) -> List[LaneInfo]: ...

    def GetJunctions(self, point: Vec2d,
                     distance: float) -> List[JunctionInfo]: ...

    def GetCrosswalks(self, point: Vec2d,
                      distance: float) -> List[CrosswalkInfo]: ...

    def GetRoads(self, point: Vec2d, distance: float) -> List[RoadInfo]: ...

    def GetClearAreas(self, point: Vec2d,
                      distance: float) -> List[ObjectInfo]: ...

    def GetParkingSpaces(self, point: Vec2d,
                         distance: float) -> List[ParkingSpaceInfo]: ...

    def GetObjects(self, point: Vec2d,
                   distance: float) -> List[ObjectInfo]: ...

    def GetNearestLane(self, point: Vec2d) -> LaneInfo: ...

    def GetNearestJunction(self, point: Vec2d) -> JunctionInfo: ...

    def GetNearestCrosswalk(self, point: Vec2d) -> CrosswalkInfo: ...

    def GetNearestClearArea(self, point: Vec2d) -> ObjectInfo: ...

    def GetNearestParkingSpace(self, point: Vec2d) -> ParkingSpaceInfo: ...

    def GetNearestObject(self, point: Vec2d) -> ObjectInfo: ...

    def GetPoiByName(self, name: str) -> PoiInfo: ...

    def GetLanesInJunction(self, junction_id: IdInfo) -> List[LaneInfo]: ...

    def GetConnectingRoads(self, from_road_id: IdInfo,
                           to_road_id: IdInfo) -> List[RoadInfo]: ...

    def GetConnectingLanes(self, from_lane_id: IdInfo,
                           to_lane_id: IdInfo) -> List[LaneInfo]: ...

    def GetDrivingIntoJunctionLanes(
        self, junction_id: IdInfo) -> List[LanePoint]: ...

    def GetDrivingOutOfJunctionLanes(
        self, junction_id: IdInfo) -> List[LanePoint]: ...

    def GetEstimateGroundHeight(self, point: Vec2d) -> float: ...

    def GetForwardSignals(self, point: Vec2d,
                          distance: float) -> List[SignalInfo]: ...

    def GetPoisInObject(self, object_id: IdInfo) -> List[PoiInfo]: ...

    def GetDockJunctions(self) -> List[JunctionInfo]: ...
    
    def GetGirderDirections(self) -> List[GirderDisplay]: ...
    
    def GetPoiInfo(self, poi_id: IdInfo) -> tuple[List[Vec2d], Vec2d, float]: ...
    
    def GetTideBridgeInfo(self) -> tuple[List[int], List[int]]: ...
    
    def DecideTurnMode(self, vessel_head_s:float, vessel_tail_s:float, 
                       head_bridge:str, leave_bridge:str, is_head:bool, 
                       mode:str) -> bool: ...

class IdInfo:
    def __init__(self, id: int = 0) -> None: ...

    def to_string(self) -> str: ...

    def value(self) -> int: ...


class LaneIndexInfo:
    def road_id(self) -> int: ...

    def lane_section_index(self) -> int: ...

    def lane_index(self) -> int: ...


class LaneBoundaryTypeWithRange:
    def type(self) -> None: ...

    def color(self) -> None: ...

    def is_left(self) -> None: ...

    def is_right(self) -> None: ...

    def cross_allowed(self) -> None: ...


class AttributesInfo:
    def SetAttribute(self) -> None: ...

    def GetAttribute(self) -> None: ...

    def attributes(self) -> None: ...


class LineStringDataInfo:
    def id(self) -> IdInfo: ...

    def points(self) -> List[Vec2d]: ...

    def type(self) -> int: ...

    def color(self) -> int: ...

    def line_string_data_pb(self) -> str: ...


class LineStringInfo:
    def id(self) -> IdInfo: ...

    def is_reverse(self) -> bool: ...

    def type(self) -> int: ...

    def color(self) -> int: ...

    def front(self) -> Vec2d: ...

    def back(self) -> Vec2d: ...

    def begin(self) -> None: ...

    def end(self) -> None: ...

    def data(self) -> LineStringDataInfo: ...

    def GetReverseLineString(self) -> None: ...

    def Reverse(self) -> None: ...


class CurveInfo:
    def lines(self) -> None: ...

    def front(self) -> None: ...

    def back(self) -> None: ...

    def begin(self) -> None: ...

    def end(self) -> None: ...

    def GetReverseCurve(self) -> None: ...


class LaneLinkInfo:
    def from_lane(self) -> LaneInfo: ...

    def from_s(self) -> float: ...

    def to_lane(self) -> LaneInfo: ...

    def to_s(self) -> float: ...


class LaneInfo:
    def lane_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def type(self) -> int: ...

    def turn_type(self) -> int: ...

    def max_speed_limit(self) -> float: ...

    def min_speed_limit(self) -> float: ...

    def prefer_speed_limit(self) -> float: ...

    def junction_id(self) -> IdInfo: ...

    def junction(self) -> JunctionInfo: ...

    def IsInJunction(self) -> bool: ...

    def left_boundary(self) -> CurveInfo: ...

    def left_boundary_types(self) -> List[LaneBoundaryTypeWithRange]: ...

    def GetLeftBoundaryType(self) -> int: ...

    def right_boundary(self) -> CurveInfo: ...

    def right_boundary_types(self) -> List[LaneBoundaryTypeWithRange]: ...

    def GetRightBoundaryType(self) -> int: ...

    def reference_line(self) -> ReferenceLine: ...

    def length(self) -> float: ...

    def successor_lane_links(self) -> List[LaneLinkInfo]: ...

    def predecessor_lane_links(self) -> List[LaneLinkInfo]: ...

    def left_neighbor_forward_lane(self) -> LaneInfo: ...

    def right_neighbor_forward_lane(self) -> LaneInfo: ...

    def bi_direction_lane(self) -> LaneIndo: ...

    def left_neighbor_reverse_lanes(self) -> List[LaneInfo]: ...

    def right_neighbor_reverse_lanes(self) -> List[LaneInfo]: ...

    def left_neighbor_forward_driving_lane(self) -> LaneInfo: ...

    def right_neighbor_forward_driving_lane(self) -> LaneInfo: ...

    def polygon(self) -> Polygon2d: ...

    def lane_section(self) -> LaneSectionInfo: ...

    def road(self) -> RoadInfo: ...

    def attributes(self) -> AttributesInfo: ...

    def lanes(self) -> List[RelationInfo]: ...

    def stop_lines(self) -> List[StopLineInfo]: ...

    def stop_line_overlaps(self) -> List[StopLineInfo]: ...

    def crosswalks(self) -> List[RelationInfo]: ...

    def pull_over_region_relations(self) -> List[RelationInfo]: ...

    def pois(self) -> List[RelationInfo]: ...

    def clear_areas(self) -> List[RelationInfo]: ...

    def pull_over_regions(self) -> List[PullOverRegionInfo]: ...

    def parking_spaces(self) -> List[ParkingSpaceInfo]: ...

    def objects(self) -> List[RelationInfo]: ...

    def lane_priority(self) -> int: ...

    def is_waiting_area(self) -> bool: ...

    def GetProjection(self, point: Vec2d) -> Tuple[float, float]: ...

    def GetPoint(self, s: float, d: float, point: Vec2d) -> None: ...

    def GetHeading(self, s: float) -> float: ...

    def GetWidth(self, s: float) -> Tuple[float, float]: ...


class LaneSectionInfo:
    def lane_section_pb(self) -> str: ...

    def lanes(self) -> List[LaneInfo]: ...

    def prev_lane_section(self) -> LaneSectionInfo: ...

    def next_lane_section(self) -> LaneSectionInfo: ...

    def road(self) -> RoadInfo: ...


class RoadInfo:
    def road_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def lane_sections(self) -> List[LaneSectionInfo]: ...

    def junction(self) -> JunctionInfo: ...

    def IsInJunction(self) -> bool: ...

    def next_roads(self) -> List[RoadInfo]: ...

    def prev_roads(self) -> List[RoadInfo]: ...

    def prev_junction(self) -> JunctionInfo: ...

    def next_junction(self) -> JunctionInfo: ...

    def polygon(self) -> Polygon2d: ...

    def attributes(self) -> AttributesInfo: ...

    def name(self) -> str: ...

    def road_struct(self) -> RoadStructInfo: ...


class JunctionInfo:
    def junction_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def polygon(self) -> Polygon2d: ...

    def name(self) -> str: ...

    def roads(self) -> List[RoadInfo]: ...

    def attributes(self) -> AttributesInfo: ...

    def is_virtual_junction(self) -> bool: ...


class CrosswalkInfo:
    def crosswalk_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def left_boundary(self) -> CurveInfo: ...

    def right_boundary(self) -> CurveInfo: ...

    def polygon(self) -> Polygon2d: ...

    def attributes(self) -> AttributesInfo: ...

    def lanes(self) -> List[RelationInfo]: ...


class StopLineInfo:
    def stop_line_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def curve(self) -> CurveInfo: ...

    def lanes(self) -> List[RelationInfo]: ...

    def signals(self) -> List[RelationInfo]: ...


class SignalInfo:
    def signal_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def polygon(self) -> Polygon2d: ...

    def stop_lines(self) -> List[RelationInfo]: ...

    def signal_type(self) -> int: ...

    def combination_type(self) -> int: ...

    def signal_center(self) -> Vec2d: ...


class PullOverRegionInfo:
    def pull_over_region_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def pois(self) -> List[RelationInfo]: ...

    def lane(self) -> LaneInfo: ...

    def start_s(self) -> float: ...

    def end_s(self) -> float: ...

    def d(self) -> float: ...


class ParkingSpaceInfo:
    def parking_space_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def left_boundary(self) -> CurveInfo: ...

    def right_boundary(self) -> CurveInfo: ...

    def reference_line(self) -> ReferenceLine: ...

    def polygon(self) -> Polygon2d: ...

    def in_lanes(self) -> List[Tuple[LaneInfo, float]]: ...

    def out_lanes(self) -> List[Tuple[LaneInfo, float]]: ...

    def pois(self) -> List[RelationInfo]: ...


class PoiInfo:
    def poi_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def type(self) -> int: ...

    def name(self) -> str: ...

    def lanes(self) -> List[RelationInfo]: ...

    def pull_over_regions(self) -> List[RelationInfo]: ...

    def parking_spaces(self) -> List[RelationInfo]: ...


class ObjectInfo:
    def object_pb(self) -> str: ...

    def id(self) -> IdInfo: ...

    def type(self) -> int: ...

    def polygon(self) -> Polygon2d: ...

    def height(self) -> float: ...

    def lanes(self) -> List[RelationInfo]: ...


class RelationInfo:
    def relation_pb(self) -> str: ...

    def this_id(self) -> IdInfo: ...

    def this_lane_overlap_range(self) -> Range: ...

    def other_id(self) -> IdInfo: ...

    def other_lane_overlap_range(self) -> Range: ...


class RoadStructInfo:
    def road_struct_pb(self) -> str: ...

    def road_name(self) -> str: ...

    def road(self) -> RoadInfo: ...

    def GetLaneIndexById(self, id: IdInfo) -> LaneIndexInfo: ...


class MapInfo:

    def lines(self) -> List[LineStringDataInfo]: ...

    def lanes(self) -> List[LaneInfo]: ...

    def roads(self) -> List[RoadInfo]: ...

    def junctions(self) -> List[JunctionInfo]: ...

    def crosswalks(self) -> List[CrosswalkInfo]: ...

    def stop_lines(self) -> List[StopLineInfo]: ...

    def parking_spaces(self) -> List[ParkingSpaceInfo]: ...

    def pull_over_regions(self) -> List[PullOverRegionInfo]: ...

    def pois(self) -> List[PoiInfo]: ...

    def objects(self) -> List[ObjectInfo]: ...

    def lane_links(self) -> List[LaneLinkInfo]: ...

    def relations(self) -> List[RelationInfo]: ...

    def road_structs(self) -> List[RoadStructInfo]: ...

    def clear(self) -> None: ...


class Range:

    def __init__(self, start, end) -> None: ...

    def start(self) -> float: ...

    def end(self) -> float: ...

    def length(self) -> float: ...

    def Contains(self, value: float) -> bool: ...


class ReferencePoint:

    def __init__(self, x, y, heading, kappa, dkappa, s) -> None: ...

    def s(self) -> float: ...

    def kappa(self) -> float: ...

    def dkappa(self) -> float: ...

    def heading(self) -> float: ...

    def set_s(self, s: float) -> None: ...

    def DebugString(self) -> str: ...


class ReferenceLine:

    def __init__(self, reference_points: List[ReferencePoint]) -> None: ...

    def Stitch(self, other: ReferenceLine,
               start_s: float, end_s: float) -> bool: ...

    def reference_points(self) -> List[ReferencePoint]: ...

    def segments(self) -> List[LineSegment2d]: ...

    def GetReferencePoint(self, s) -> ReferencePoint: ...

    def SDToXY(self, sd_point: SDPoint, xy_point: Vec2d) -> None: ...

    def XYToSD(self, xy_point: Vec2d, sd_point: SDPoint) -> None: ...

    def Translate(self, d) -> None: ...

    def length(self) -> float: ...

    def curve_degree(self) -> float: ...

    def min_curvature_radius(self) -> float: ...

    def min_curvature_radius_s(self) -> float: ...

    def DebugString(self) -> str: ...

    def InitKDTree(self) -> None: ...


class OneExtendConfig:
    def __init__(self) -> None: ...

    @property
    def extend_dist(self) -> float: ...

    @property
    def has_extend_radius(self) -> bool: ...

    @property
    def extend_radius(self) -> float: ...

    @property
    def has_extend_rotate_angle(self) -> bool: ...

    @property
    def extend_rotate_angle(self) -> float: ...


class BezierConfig:
    def __init__(self) -> None: ...

    @property
    def bezier_dist_ratio_from_first(self) -> float: ...

    @property
    def bezier_dist_ratio_from_second(self) -> float: ...

    @property
    def bezier_dist_ratio_to_first(self) -> float: ...

    @property
    def bezier_dist_ratio_to_second(self) -> float: ...


class BlockLane:
    def __init__(self, lane_id: str, start_s: float, end_s: float) -> None: ...

    @property
    def lane_id(self) -> str: ...

    @property
    def start_s(self) -> float: ...

    @property
    def end_s(self) -> float: ...


class HdmapVessel:
    def __init__(self, vessel_uuid: str, head_s: float,
                 rear_s: float) -> None: ...

    @property
    def vessel_uuid(self) -> str: ...

    @property
    def head_s(self) -> float: ...

    @property
    def rear_s(self) -> float: ...

class BridgeMode:
    def __init__(self, bridge_name: str, mode: int) -> None: ...

    @property
    def bridge_name(self) -> str: ...
    
    @property
    def mode(self) -> int: ...

class CloudServiceVessel:
    def __init__(self)  -> None: ...
    
    @property
    def uuid(self) -> str: ...
    
    def set_uuid(self) -> None: ...
    
class GirderStatus:
    def __init__(self, has_this_area: bool, start_s: float,
                 end_s: float, girder_direction: int) -> None: ...

    @property
    def has_this_area(self) -> bool: ...

    @property
    def start_s(self) -> float: ...

    @property
    def end_s(self) -> float: ...
    
    @property
    def girder_direction(self) -> int: ...
    
class GirderAffect:
    
    def __init__(self, affect_level: int, affect_uuid: str, 
                 affect_direction: int) -> None: ...
    
    @property
    def affect_level(self) -> int: ...
    
    @property
    def affect_uuid(self) -> str: ...
    
    @property
    def affect_direction(self) ->int: ...
    
class GirderDisplay:
    
    def __init__(self) -> None: ...
    
    @property
    def polygon_points(self) -> List[Vec2d]: ...
    
    @property
    def center_point(self) -> Vec2d: ...
    
    @property
    def heading(self) -> float: ...

class Utils:
    @staticmethod
    def FitOneVirtualReferenceLine(
        from_reference_line: ReferenceLine, to_reference_line: ReferenceLine,
        lane_turn_type: int, from_extend: OneExtendConfig, to_extend: OneExtendConfig, bezier_config: BezierConfig,
        virtual_reference_line: ReferenceLine, show_debug: bool) -> bool: ...

    @staticmethod
    def BuildCentralReferenceLine(left_marking_line_bytes: str, right_marking_line_bytes: str,
                                  need_smooth: bool, reference_line: ReferenceLine) -> bool: ...

    @staticmethod
    def SetReferenceLineSmootherConfig(smoother_config_bytes: str) -> None: ...

    @staticmethod
    def BuildReferenceLineFromPoints(
        self, points: List[Vec2d], reference_line: ReferenceLine) -> bool: ...

    @staticmethod
    def GetBoundaryLineSegments(
        one_lane: LaneInfo, one_line_segments: list[LineSegment2d]) -> list[LineSegment2d]: ...

    @staticmethod
    def ShrinkLineSegments(
        one_line_segments: list[LineSegment2d]) -> list[LineSegment2d]: ...

    @staticmethod
    def GetLineSegmentsIntersectPolygon(one_line_segments: list[LineSegment2d],
                                        one_ref_line: ReferenceLine, anther_polygon: Polygon2d) -> list[(float, float)]: ...

    @staticmethod
    def BuildPointsFromCurve(curve_info: CurveInfo,
                             points: list[Vec2d]) -> None: ...



from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.hdmap_impl.geometry import CurveImpl

class StopLineImpl:
  def __init__(self) -> None:
    self._id = 0
    self._curve = CurveImpl()
    self._lanes:list[RelationImpl] = []
    self._signals:list[RelationImpl] = []
    
  def id(self):
    return self._id

  def curve(self):
    return self._curve
  
  def lanes(self):
    return self._lanes
  
  def signals(self):
    return self._signals


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/junction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2
from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import attribute_pb2 as proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/junction.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$proto/hdmap_lib/proto/junction.proto\x12\thdmap_lib\x1a$proto/hdmap_lib/proto/geometry.proto\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a%proto/hdmap_lib/proto/attribute.proto\"\xe5\x02\n\x08Junction\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12#\n\x07polygon\x18\x02 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x12(\n\nattributes\x18\x03 \x03(\x0b\x32\x14.hdmap_lib.Attribute\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13is_virtual_junction\x18\x05 \x01(\x08\x12&\n\x04type\x18\x06 \x01(\x0e\x32\x18.hdmap_lib.Junction.Type\x12\x1f\n\x08road_ids\x18\x07 \x03(\x0b\x32\r.hdmap_lib.Id\"{\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nT_JUNCTION\x10\x02\x12\x0e\n\nY_JUNCTION\x10\x03\x12\x0e\n\nX_JUNCTION\x10\x06\x12\x1c\n\x18\x42RIDGE_ENTRANCE_JUNCTION\x10\x08\x12\x18\n\x14\x42RIDGE_EXIT_JUNCTION\x10\t'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2.DESCRIPTOR,])



_JUNCTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hdmap_lib.Junction.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='T_JUNCTION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Y_JUNCTION', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X_JUNCTION', index=3, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_ENTRANCE_JUNCTION', index=4, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRIDGE_EXIT_JUNCTION', index=5, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=395,
  serialized_end=518,
)
_sym_db.RegisterEnumDescriptor(_JUNCTION_TYPE)


_JUNCTION = _descriptor.Descriptor(
  name='Junction',
  full_name='hdmap_lib.Junction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Junction.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.Junction.polygon', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='hdmap_lib.Junction.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='hdmap_lib.Junction.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_virtual_junction', full_name='hdmap_lib.Junction.is_virtual_junction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Junction.type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_ids', full_name='hdmap_lib.Junction.road_ids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JUNCTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=518,
)

_JUNCTION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_JUNCTION.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_JUNCTION.fields_by_name['attributes'].message_type = proto_dot_hdmap__lib_dot_proto_dot_attribute__pb2._ATTRIBUTE
_JUNCTION.fields_by_name['type'].enum_type = _JUNCTION_TYPE
_JUNCTION.fields_by_name['road_ids'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_JUNCTION_TYPE.containing_type = _JUNCTION
DESCRIPTOR.message_types_by_name['Junction'] = _JUNCTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Junction = _reflection.GeneratedProtocolMessageType('Junction', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTION,
  '__module__' : 'proto.hdmap_lib.proto.junction_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Junction)
  })
_sym_db.RegisterMessage(Junction)


# @@protoc_insertion_point(module_scope)



from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl

class PullOverRegionImpl:
  def __init__(self) -> None:
    self._id = 0
    self._pois:list[RelationImpl] = []
    self._lane_id = 0
    self._start_s = 0
    self._end_s = 0
    self._d = 0
    
  def id(self):
    return self._id
  
  def pois(self):
    return self._pois
  
  def lane(self):
    return self._lane_id
  
  def start_s(self):
    return self._start_s
  
  def end_s(self):
    return self._end_s
  
  def d(self):
    return self._d


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/parking_space.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2
from proto.hdmap_lib.proto import geometry_pb2 as proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/parking_space.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)proto/hdmap_lib/proto/parking_space.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\x1a$proto/hdmap_lib/proto/geometry.proto\"\xe8\x02\n\x0cParkingSpace\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\'\n\rleft_boundary\x18\x02 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12(\n\x0eright_boundary\x18\x03 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\'\n\rcentral_curve\x18\x06 \x01(\x0b\x32\x10.hdmap_lib.Curve\x12\x33\n\x08in_lanes\x18\x04 \x03(\x0b\x32!.hdmap_lib.ParkingSpace.LanePoint\x12\x34\n\tout_lanes\x18\x05 \x03(\x0b\x32!.hdmap_lib.ParkingSpace.LanePoint\x12#\n\x07polygon\x18\x07 \x01(\x0b\x32\x12.hdmap_lib.Polygon\x1a\x31\n\tLanePoint\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\t\n\x01s\x18\x02 \x01(\x01\"v\n\x0ePullOverRegion\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x1e\n\x07lane_id\x18\x02 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x0f\n\x07start_s\x18\x03 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x04 \x01(\x01\x12\t\n\x01\x64\x18\x05 \x01(\x01'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_PARKINGSPACE_LANEPOINT = _descriptor.Descriptor(
  name='LanePoint',
  full_name='hdmap_lib.ParkingSpace.LanePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ParkingSpace.LanePoint.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='hdmap_lib.ParkingSpace.LanePoint.s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=487,
)

_PARKINGSPACE = _descriptor.Descriptor(
  name='ParkingSpace',
  full_name='hdmap_lib.ParkingSpace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ParkingSpace.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_boundary', full_name='hdmap_lib.ParkingSpace.left_boundary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_boundary', full_name='hdmap_lib.ParkingSpace.right_boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='central_curve', full_name='hdmap_lib.ParkingSpace.central_curve', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='in_lanes', full_name='hdmap_lib.ParkingSpace.in_lanes', index=4,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='out_lanes', full_name='hdmap_lib.ParkingSpace.out_lanes', index=5,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='hdmap_lib.ParkingSpace.polygon', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PARKINGSPACE_LANEPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=127,
  serialized_end=487,
)


_PULLOVERREGION = _descriptor.Descriptor(
  name='PullOverRegion',
  full_name='hdmap_lib.PullOverRegion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.PullOverRegion.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='hdmap_lib.PullOverRegion.lane_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_s', full_name='hdmap_lib.PullOverRegion.start_s', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='hdmap_lib.PullOverRegion.end_s', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='hdmap_lib.PullOverRegion.d', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=607,
)

_PARKINGSPACE_LANEPOINT.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PARKINGSPACE_LANEPOINT.containing_type = _PARKINGSPACE
_PARKINGSPACE.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PARKINGSPACE.fields_by_name['left_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['right_boundary'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['central_curve'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._CURVE
_PARKINGSPACE.fields_by_name['in_lanes'].message_type = _PARKINGSPACE_LANEPOINT
_PARKINGSPACE.fields_by_name['out_lanes'].message_type = _PARKINGSPACE_LANEPOINT
_PARKINGSPACE.fields_by_name['polygon'].message_type = proto_dot_hdmap__lib_dot_proto_dot_geometry__pb2._POLYGON
_PULLOVERREGION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_PULLOVERREGION.fields_by_name['lane_id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
DESCRIPTOR.message_types_by_name['ParkingSpace'] = _PARKINGSPACE
DESCRIPTOR.message_types_by_name['PullOverRegion'] = _PULLOVERREGION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParkingSpace = _reflection.GeneratedProtocolMessageType('ParkingSpace', (_message.Message,), {

  'LanePoint' : _reflection.GeneratedProtocolMessageType('LanePoint', (_message.Message,), {
    'DESCRIPTOR' : _PARKINGSPACE_LANEPOINT,
    '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
    # @@protoc_insertion_point(class_scope:hdmap_lib.ParkingSpace.LanePoint)
    })
  ,
  'DESCRIPTOR' : _PARKINGSPACE,
  '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ParkingSpace)
  })
_sym_db.RegisterMessage(ParkingSpace)
_sym_db.RegisterMessage(ParkingSpace.LanePoint)

PullOverRegion = _reflection.GeneratedProtocolMessageType('PullOverRegion', (_message.Message,), {
  'DESCRIPTOR' : _PULLOVERREGION,
  '__module__' : 'proto.hdmap_lib.proto.parking_space_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PullOverRegion)
  })
_sym_db.RegisterMessage(PullOverRegion)


# @@protoc_insertion_point(module_scope)



from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.hdmap_impl.geometry import CurveImpl
from pyhdmap.remote.hdmap_impl.attribute_impl import AttributesImpl

class CrosswalkImpl:
  def __init__(self) -> None:
    self._id = 0
    self._left_boundary = CurveImpl()
    self._right_boundary = CurveImpl()
    self._polygon = Polygon2d()
    self._attributes = AttributesImpl()
    self._lanes:list[RelationImpl] = []
    
  def id(self):
    return self._id
  
  def left_boundary(self):
    return self._left_boundary
  
  def right_boundary(self):
    return self._right_boundary
  
  def polygon(self):
    return self._polygon
  
  def attributes(self):
    return self._attributes
  
  def lanes(self):
    return self._lanes


from proto.hdmap_lib.proto import junction_pb2
from externals.libhdmap import *
from pyhdmap.remote.hdmap_impl.relation_impl import RelationImpl
from pyhdmap.remote.hdmap_impl.geometry import CurveImpl
from pyhdmap.remote.hdmap_impl.attribute_impl import AttributesImpl

class JunctionImpl:
  def __init__(self) -> None:
    self._id = 0
    self._polygon = Polygon2d()
    self._type = junction_pb2.Junction.Type.UNKNOWN
    self._name = ""
    self._is_virtual_junction = False
    self._road_ids = []
    self._road_links = []
    self._lanes:list[RelationImpl] = []
    self._attributes = AttributesImpl()
    
  def id(self):
    return self._id
  
  def polygon(self):
    return self._polygon
  
  def type(self):
    return self._type
  
  def name(self):
    return self._name
  
  def is_virtual_junction(self):
    return self._is_virtual_junction
  
  def roads(self):
    return self._road_ids
  
  def road_links(self):
    return self._road_links
  
  def attributes(self):
    return self._attributes
  
  def lanes(self):
    return self._lanes


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/hdmap_lib/proto/relation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from proto.hdmap_lib.proto import id_pb2 as proto_dot_hdmap__lib_dot_proto_dot_id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/hdmap_lib/proto/relation.proto',
  package='hdmap_lib',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$proto/hdmap_lib/proto/relation.proto\x12\thdmap_lib\x1a\x1eproto/hdmap_lib/proto/id.proto\"1\n\x0fLaneOverlapInfo\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\"p\n\x12ObjectRelationInfo\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12\x37\n\x11lane_overlap_info\x18\x02 \x01(\x0b\x32\x1a.hdmap_lib.LaneOverlapInfoH\x00\x42\x06\n\x04info\"w\n\x0fLaneLaneOverlap\x12/\n\x08one_lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x33\n\x0c\x61nother_lane\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"u\n\x14LaneCrosswalkOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tcrosswalk\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"t\n\x13LaneStopLineOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tstop_line\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"v\n\x14LaneClearAreaOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x31\n\nclear_area\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"s\n\x13LaneJunctionOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12/\n\x08junction\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x85\x01\n\x1bTrafficLightStopLineOverlap\x12\x34\n\rtraffic_light\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x30\n\tstop_line\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x80\x01\n\x19PoiPullOverRegionRelation\x12*\n\x03poi\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x37\n\x10pull_over_region\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"{\n\x17PoiParkingSpaceRelation\x12*\n\x03poi\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x34\n\rparking_space\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x82\x01\n\x1aLanePullOverRegionRelation\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12\x37\n\x10pull_over_region\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"j\n\x0fLanePoiRelation\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12*\n\x03poi\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"o\n\x11LaneObjectOverlap\x12+\n\x04lane\x18\x01 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\x12-\n\x06object\x18\x02 \x01(\x0b\x32\x1d.hdmap_lib.ObjectRelationInfo\"\x83\x08\n\x08Relation\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.hdmap_lib.Id\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .hdmap_lib.Relation.RelationType\x12<\n\x16lane_lane_overlap_info\x18\x06 \x01(\x0b\x32\x1a.hdmap_lib.LaneLaneOverlapH\x00\x12\x46\n\x1blane_crosswalk_overlap_info\x18\x03 \x01(\x0b\x32\x1f.hdmap_lib.LaneCrosswalkOverlapH\x00\x12\x45\n\x1blane_stop_line_overlap_info\x18\x04 \x01(\x0b\x32\x1e.hdmap_lib.LaneStopLineOverlapH\x00\x12L\n\x1atraffic_light_overlap_info\x18\x05 \x01(\x0b\x32&.hdmap_lib.TrafficLightStopLineOverlapH\x00\x12R\n\"poi_pull_over_region_relation_info\x18\x07 \x01(\x0b\x32$.hdmap_lib.PoiPullOverRegionRelationH\x00\x12M\n\x1fpoi_parking_space_relation_info\x18\x0b \x01(\x0b\x32\".hdmap_lib.PoiParkingSpaceRelationH\x00\x12<\n\x16lane_poi_relation_info\x18\t \x01(\x0b\x32\x1a.hdmap_lib.LanePoiRelationH\x00\x12@\n\x18lane_object_overlap_info\x18\x0c \x01(\x0b\x32\x1c.hdmap_lib.LaneObjectOverlapH\x00\x12\x44\n\x1alane_junction_overlap_info\x18\r \x01(\x0b\x32\x1e.hdmap_lib.LaneJunctionOverlapH\x00\"\x96\x02\n\x0cRelationType\x12\x16\n\x12RELATION_LANE_LANE\x10\x01\x12\x1b\n\x17RELATION_LANE_CROSSWALK\x10\x02\x12\x1b\n\x17RELATION_LANE_STOP_LINE\x10\x03\x12$\n RELATION_TRAFFIC_LIGHT_STOP_LINE\x10\x04\x12!\n\x1dRELATION_POI_PULL_OVER_REGION\x10\x05\x12\x1e\n\x1aRELATION_POI_PARKING_SPACE\x10\x08\x12\x15\n\x11RELATION_LANE_POI\x10\x06\x12\x18\n\x14RELATION_LANE_OBJECT\x10\t\x12\x1a\n\x16RELATION_LANE_JUNCTION\x10\nB\x0f\n\rrelation_info'
  ,
  dependencies=[proto_dot_hdmap__lib_dot_proto_dot_id__pb2.DESCRIPTOR,])



_RELATION_RELATIONTYPE = _descriptor.EnumDescriptor(
  name='RelationType',
  full_name='hdmap_lib.Relation.RelationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_LANE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_CROSSWALK', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_STOP_LINE', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_TRAFFIC_LIGHT_STOP_LINE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_POI_PULL_OVER_REGION', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_POI_PARKING_SPACE', index=5, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_POI', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_OBJECT', index=7, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATION_LANE_JUNCTION', index=8, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2322,
  serialized_end=2600,
)
_sym_db.RegisterEnumDescriptor(_RELATION_RELATIONTYPE)


_LANEOVERLAPINFO = _descriptor.Descriptor(
  name='LaneOverlapInfo',
  full_name='hdmap_lib.LaneOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='hdmap_lib.LaneOverlapInfo.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='hdmap_lib.LaneOverlapInfo.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=132,
)


_OBJECTRELATIONINFO = _descriptor.Descriptor(
  name='ObjectRelationInfo',
  full_name='hdmap_lib.ObjectRelationInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.ObjectRelationInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_overlap_info', full_name='hdmap_lib.ObjectRelationInfo.lane_overlap_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='info', full_name='hdmap_lib.ObjectRelationInfo.info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=134,
  serialized_end=246,
)


_LANELANEOVERLAP = _descriptor.Descriptor(
  name='LaneLaneOverlap',
  full_name='hdmap_lib.LaneLaneOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='one_lane', full_name='hdmap_lib.LaneLaneOverlap.one_lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='another_lane', full_name='hdmap_lib.LaneLaneOverlap.another_lane', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=367,
)


_LANECROSSWALKOVERLAP = _descriptor.Descriptor(
  name='LaneCrosswalkOverlap',
  full_name='hdmap_lib.LaneCrosswalkOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneCrosswalkOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='hdmap_lib.LaneCrosswalkOverlap.crosswalk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=486,
)


_LANESTOPLINEOVERLAP = _descriptor.Descriptor(
  name='LaneStopLineOverlap',
  full_name='hdmap_lib.LaneStopLineOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneStopLineOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='hdmap_lib.LaneStopLineOverlap.stop_line', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=488,
  serialized_end=604,
)


_LANECLEARAREAOVERLAP = _descriptor.Descriptor(
  name='LaneClearAreaOverlap',
  full_name='hdmap_lib.LaneClearAreaOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneClearAreaOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area', full_name='hdmap_lib.LaneClearAreaOverlap.clear_area', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=724,
)


_LANEJUNCTIONOVERLAP = _descriptor.Descriptor(
  name='LaneJunctionOverlap',
  full_name='hdmap_lib.LaneJunctionOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneJunctionOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='hdmap_lib.LaneJunctionOverlap.junction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=726,
  serialized_end=841,
)


_TRAFFICLIGHTSTOPLINEOVERLAP = _descriptor.Descriptor(
  name='TrafficLightStopLineOverlap',
  full_name='hdmap_lib.TrafficLightStopLineOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='hdmap_lib.TrafficLightStopLineOverlap.traffic_light', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_line', full_name='hdmap_lib.TrafficLightStopLineOverlap.stop_line', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=844,
  serialized_end=977,
)


_POIPULLOVERREGIONRELATION = _descriptor.Descriptor(
  name='PoiPullOverRegionRelation',
  full_name='hdmap_lib.PoiPullOverRegionRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.PoiPullOverRegionRelation.poi', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region', full_name='hdmap_lib.PoiPullOverRegionRelation.pull_over_region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=980,
  serialized_end=1108,
)


_POIPARKINGSPACERELATION = _descriptor.Descriptor(
  name='PoiParkingSpaceRelation',
  full_name='hdmap_lib.PoiParkingSpaceRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.PoiParkingSpaceRelation.poi', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space', full_name='hdmap_lib.PoiParkingSpaceRelation.parking_space', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1233,
)


_LANEPULLOVERREGIONRELATION = _descriptor.Descriptor(
  name='LanePullOverRegionRelation',
  full_name='hdmap_lib.LanePullOverRegionRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LanePullOverRegionRelation.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pull_over_region', full_name='hdmap_lib.LanePullOverRegionRelation.pull_over_region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1236,
  serialized_end=1366,
)


_LANEPOIRELATION = _descriptor.Descriptor(
  name='LanePoiRelation',
  full_name='hdmap_lib.LanePoiRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LanePoiRelation.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi', full_name='hdmap_lib.LanePoiRelation.poi', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1368,
  serialized_end=1474,
)


_LANEOBJECTOVERLAP = _descriptor.Descriptor(
  name='LaneObjectOverlap',
  full_name='hdmap_lib.LaneObjectOverlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='hdmap_lib.LaneObjectOverlap.lane', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='hdmap_lib.LaneObjectOverlap.object', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=1587,
)


_RELATION = _descriptor.Descriptor(
  name='Relation',
  full_name='hdmap_lib.Relation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hdmap_lib.Relation.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='hdmap_lib.Relation.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_lane_overlap_info', full_name='hdmap_lib.Relation.lane_lane_overlap_info', index=2,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_crosswalk_overlap_info', full_name='hdmap_lib.Relation.lane_crosswalk_overlap_info', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_stop_line_overlap_info', full_name='hdmap_lib.Relation.lane_stop_line_overlap_info', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_overlap_info', full_name='hdmap_lib.Relation.traffic_light_overlap_info', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_pull_over_region_relation_info', full_name='hdmap_lib.Relation.poi_pull_over_region_relation_info', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='poi_parking_space_relation_info', full_name='hdmap_lib.Relation.poi_parking_space_relation_info', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_poi_relation_info', full_name='hdmap_lib.Relation.lane_poi_relation_info', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_object_overlap_info', full_name='hdmap_lib.Relation.lane_object_overlap_info', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_junction_overlap_info', full_name='hdmap_lib.Relation.lane_junction_overlap_info', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RELATION_RELATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='relation_info', full_name='hdmap_lib.Relation.relation_info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1590,
  serialized_end=2617,
)

_OBJECTRELATIONINFO.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'].message_type = _LANEOVERLAPINFO
_OBJECTRELATIONINFO.oneofs_by_name['info'].fields.append(
  _OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'])
_OBJECTRELATIONINFO.fields_by_name['lane_overlap_info'].containing_oneof = _OBJECTRELATIONINFO.oneofs_by_name['info']
_LANELANEOVERLAP.fields_by_name['one_lane'].message_type = _OBJECTRELATIONINFO
_LANELANEOVERLAP.fields_by_name['another_lane'].message_type = _OBJECTRELATIONINFO
_LANECROSSWALKOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANECROSSWALKOVERLAP.fields_by_name['crosswalk'].message_type = _OBJECTRELATIONINFO
_LANESTOPLINEOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANESTOPLINEOVERLAP.fields_by_name['stop_line'].message_type = _OBJECTRELATIONINFO
_LANECLEARAREAOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANECLEARAREAOVERLAP.fields_by_name['clear_area'].message_type = _OBJECTRELATIONINFO
_LANEJUNCTIONOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEJUNCTIONOVERLAP.fields_by_name['junction'].message_type = _OBJECTRELATIONINFO
_TRAFFICLIGHTSTOPLINEOVERLAP.fields_by_name['traffic_light'].message_type = _OBJECTRELATIONINFO
_TRAFFICLIGHTSTOPLINEOVERLAP.fields_by_name['stop_line'].message_type = _OBJECTRELATIONINFO
_POIPULLOVERREGIONRELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_POIPULLOVERREGIONRELATION.fields_by_name['pull_over_region'].message_type = _OBJECTRELATIONINFO
_POIPARKINGSPACERELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_POIPARKINGSPACERELATION.fields_by_name['parking_space'].message_type = _OBJECTRELATIONINFO
_LANEPULLOVERREGIONRELATION.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEPULLOVERREGIONRELATION.fields_by_name['pull_over_region'].message_type = _OBJECTRELATIONINFO
_LANEPOIRELATION.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEPOIRELATION.fields_by_name['poi'].message_type = _OBJECTRELATIONINFO
_LANEOBJECTOVERLAP.fields_by_name['lane'].message_type = _OBJECTRELATIONINFO
_LANEOBJECTOVERLAP.fields_by_name['object'].message_type = _OBJECTRELATIONINFO
_RELATION.fields_by_name['id'].message_type = proto_dot_hdmap__lib_dot_proto_dot_id__pb2._ID
_RELATION.fields_by_name['type'].enum_type = _RELATION_RELATIONTYPE
_RELATION.fields_by_name['lane_lane_overlap_info'].message_type = _LANELANEOVERLAP
_RELATION.fields_by_name['lane_crosswalk_overlap_info'].message_type = _LANECROSSWALKOVERLAP
_RELATION.fields_by_name['lane_stop_line_overlap_info'].message_type = _LANESTOPLINEOVERLAP
_RELATION.fields_by_name['traffic_light_overlap_info'].message_type = _TRAFFICLIGHTSTOPLINEOVERLAP
_RELATION.fields_by_name['poi_pull_over_region_relation_info'].message_type = _POIPULLOVERREGIONRELATION
_RELATION.fields_by_name['poi_parking_space_relation_info'].message_type = _POIPARKINGSPACERELATION
_RELATION.fields_by_name['lane_poi_relation_info'].message_type = _LANEPOIRELATION
_RELATION.fields_by_name['lane_object_overlap_info'].message_type = _LANEOBJECTOVERLAP
_RELATION.fields_by_name['lane_junction_overlap_info'].message_type = _LANEJUNCTIONOVERLAP
_RELATION_RELATIONTYPE.containing_type = _RELATION
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_lane_overlap_info'])
_RELATION.fields_by_name['lane_lane_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_crosswalk_overlap_info'])
_RELATION.fields_by_name['lane_crosswalk_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_stop_line_overlap_info'])
_RELATION.fields_by_name['lane_stop_line_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['traffic_light_overlap_info'])
_RELATION.fields_by_name['traffic_light_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['poi_pull_over_region_relation_info'])
_RELATION.fields_by_name['poi_pull_over_region_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['poi_parking_space_relation_info'])
_RELATION.fields_by_name['poi_parking_space_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_poi_relation_info'])
_RELATION.fields_by_name['lane_poi_relation_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_object_overlap_info'])
_RELATION.fields_by_name['lane_object_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
_RELATION.oneofs_by_name['relation_info'].fields.append(
  _RELATION.fields_by_name['lane_junction_overlap_info'])
_RELATION.fields_by_name['lane_junction_overlap_info'].containing_oneof = _RELATION.oneofs_by_name['relation_info']
DESCRIPTOR.message_types_by_name['LaneOverlapInfo'] = _LANEOVERLAPINFO
DESCRIPTOR.message_types_by_name['ObjectRelationInfo'] = _OBJECTRELATIONINFO
DESCRIPTOR.message_types_by_name['LaneLaneOverlap'] = _LANELANEOVERLAP
DESCRIPTOR.message_types_by_name['LaneCrosswalkOverlap'] = _LANECROSSWALKOVERLAP
DESCRIPTOR.message_types_by_name['LaneStopLineOverlap'] = _LANESTOPLINEOVERLAP
DESCRIPTOR.message_types_by_name['LaneClearAreaOverlap'] = _LANECLEARAREAOVERLAP
DESCRIPTOR.message_types_by_name['LaneJunctionOverlap'] = _LANEJUNCTIONOVERLAP
DESCRIPTOR.message_types_by_name['TrafficLightStopLineOverlap'] = _TRAFFICLIGHTSTOPLINEOVERLAP
DESCRIPTOR.message_types_by_name['PoiPullOverRegionRelation'] = _POIPULLOVERREGIONRELATION
DESCRIPTOR.message_types_by_name['PoiParkingSpaceRelation'] = _POIPARKINGSPACERELATION
DESCRIPTOR.message_types_by_name['LanePullOverRegionRelation'] = _LANEPULLOVERREGIONRELATION
DESCRIPTOR.message_types_by_name['LanePoiRelation'] = _LANEPOIRELATION
DESCRIPTOR.message_types_by_name['LaneObjectOverlap'] = _LANEOBJECTOVERLAP
DESCRIPTOR.message_types_by_name['Relation'] = _RELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneOverlapInfo = _reflection.GeneratedProtocolMessageType('LaneOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _LANEOVERLAPINFO,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneOverlapInfo)
  })
_sym_db.RegisterMessage(LaneOverlapInfo)

ObjectRelationInfo = _reflection.GeneratedProtocolMessageType('ObjectRelationInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRELATIONINFO,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.ObjectRelationInfo)
  })
_sym_db.RegisterMessage(ObjectRelationInfo)

LaneLaneOverlap = _reflection.GeneratedProtocolMessageType('LaneLaneOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANELANEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneLaneOverlap)
  })
_sym_db.RegisterMessage(LaneLaneOverlap)

LaneCrosswalkOverlap = _reflection.GeneratedProtocolMessageType('LaneCrosswalkOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANECROSSWALKOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneCrosswalkOverlap)
  })
_sym_db.RegisterMessage(LaneCrosswalkOverlap)

LaneStopLineOverlap = _reflection.GeneratedProtocolMessageType('LaneStopLineOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANESTOPLINEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneStopLineOverlap)
  })
_sym_db.RegisterMessage(LaneStopLineOverlap)

LaneClearAreaOverlap = _reflection.GeneratedProtocolMessageType('LaneClearAreaOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANECLEARAREAOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneClearAreaOverlap)
  })
_sym_db.RegisterMessage(LaneClearAreaOverlap)

LaneJunctionOverlap = _reflection.GeneratedProtocolMessageType('LaneJunctionOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANEJUNCTIONOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneJunctionOverlap)
  })
_sym_db.RegisterMessage(LaneJunctionOverlap)

TrafficLightStopLineOverlap = _reflection.GeneratedProtocolMessageType('TrafficLightStopLineOverlap', (_message.Message,), {
  'DESCRIPTOR' : _TRAFFICLIGHTSTOPLINEOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.TrafficLightStopLineOverlap)
  })
_sym_db.RegisterMessage(TrafficLightStopLineOverlap)

PoiPullOverRegionRelation = _reflection.GeneratedProtocolMessageType('PoiPullOverRegionRelation', (_message.Message,), {
  'DESCRIPTOR' : _POIPULLOVERREGIONRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PoiPullOverRegionRelation)
  })
_sym_db.RegisterMessage(PoiPullOverRegionRelation)

PoiParkingSpaceRelation = _reflection.GeneratedProtocolMessageType('PoiParkingSpaceRelation', (_message.Message,), {
  'DESCRIPTOR' : _POIPARKINGSPACERELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.PoiParkingSpaceRelation)
  })
_sym_db.RegisterMessage(PoiParkingSpaceRelation)

LanePullOverRegionRelation = _reflection.GeneratedProtocolMessageType('LanePullOverRegionRelation', (_message.Message,), {
  'DESCRIPTOR' : _LANEPULLOVERREGIONRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LanePullOverRegionRelation)
  })
_sym_db.RegisterMessage(LanePullOverRegionRelation)

LanePoiRelation = _reflection.GeneratedProtocolMessageType('LanePoiRelation', (_message.Message,), {
  'DESCRIPTOR' : _LANEPOIRELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LanePoiRelation)
  })
_sym_db.RegisterMessage(LanePoiRelation)

LaneObjectOverlap = _reflection.GeneratedProtocolMessageType('LaneObjectOverlap', (_message.Message,), {
  'DESCRIPTOR' : _LANEOBJECTOVERLAP,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.LaneObjectOverlap)
  })
_sym_db.RegisterMessage(LaneObjectOverlap)

Relation = _reflection.GeneratedProtocolMessageType('Relation', (_message.Message,), {
  'DESCRIPTOR' : _RELATION,
  '__module__' : 'proto.hdmap_lib.proto.relation_pb2'
  # @@protoc_insertion_point(class_scope:hdmap_lib.Relation)
  })
_sym_db.RegisterMessage(Relation)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import os
import copy
import json
import logging
from typing import Dict, List
from collections import OrderedDict

import yaml

class Singleton(type):
    """
    An metaclass for singleton purpose. Every singleton class should inherit from this class by 'metaclass=Singleton'.
    """
    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(
                Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]



class ConfigManager(metaclass=Singleton):

    def __init__(self):
        self._data_dir = None
        self._config = None

    def init_config(self, data_dir):
        self._data_dir = data_dir
        config_path = os.path.join(data_dir, "config", "service.yaml")
        self._config = yaml.load(
            open(config_path), Loader=yaml.FullLoader)
        logging.info("init config from: %s", config_path)
        
    @property
    def conf_dir(self) -> str:
        return os.path.join(self._data_dir, "config")
        
    @property
    def hdmap_lib_conf_path(self) -> str:
        return os.path.join(self.conf_dir, "hdmap_lib_conf", "hdmap_lib.conf")
      
    @staticmethod
    def _read_conf_file(conf_map: Dict[str, str], conf_file_content: str):
        lines = conf_file_content.splitlines()
        for line in lines:
            param_pair = line.strip().split("=")
            if not param_pair:
                continue
            if len(param_pair) == 1:
                conf_map[param_pair[0]] = None
            else:
                conf_map[param_pair[0]] = param_pair[1]
    
    def _get_runtime_flags(self):
        conf_map = {}
        hdmap_lib_conf = open(self.hdmap_lib_conf_path, "r").read()
        self._read_conf_file(conf_map, hdmap_lib_conf)

        if "--hdmap_lib_config_root" in conf_map:
            conf_map["--hdmap_lib_config_root"] = os.path.join(
                os.path.dirname(self.hdmap_lib_conf_path),
                conf_map["--hdmap_lib_config_root"])
        if "--driverless_road_link_config_path" in conf_map:
            conf_map["--driverless_road_link_config_path"] = os.path.join(
                os.path.dirname(self.hdmap_lib_conf_path),
                conf_map["--driverless_road_link_config_path"])
        if "--yongzhou_road_link_config_path" in conf_map:
            conf_map["--yongzhou_road_link_config_path"] = os.path.join(
                os.path.dirname(self.hdmap_lib_conf_path),
                conf_map["--yongzhou_road_link_config_path"])

        runtime_flags = "\n".join(
            [f"{k}={v}" if v is not None else f"{k}" for k, v in conf_map.items()])
        return runtime_flags






class AttributesImpl:
  def __init__(self) -> None:
    self._attributes:dict[str, str] = {}
    
  def attributes(self):
    return self._attributes
  
  def SetAttribute(self, key, value):
    self._attributes[str(key)] = str(value)
    return
  
  def GetAttribute(self, key):
    if key not in self._attributes.keys():
      return None
    return self._attributes[key]